@@ -18,7 +18,8 @@
 #
 # \value{
 #   Returns a @data.frame where the
-#   first two columns are 'chromosome' and 'x' (position)
+#   first three columns are 'chromosome', 'x' (position),
+#   and 'count' (number of loci average over for the given bin),
 #   and the remaining ones are the smoothed locus-level data.
 # }
 #
@@ -49,8 +50,10 @@ setMethodS3("getSmoothLocusData", "CBS", function(fit, by, ...) {
     bx <- seq(from=rx[1], to=rx[2], by=by);
     xS <- bx[-1] - by/2;
     yS <- binMeans(y=y, x=x, bx=bx);
-    yS[yS == 0] <- NA;
-    dataTS <- data.frame(chromosome=chr, x=xS, y=yS);
+    count <- attr(yS, "count");
+    yS[count == 0L] <- NA_real_;
+    attr(yS, "count") <- NULL;
+    dataTS <- data.frame(chromosome=chr, x=xS, count=count, y=yS);
     dataS <- rbind(dataS, dataTS);
   } # for (kk ...)
 
@@ -60,6 +63,8 @@ setMethodS3("getSmoothLocusData", "CBS", function(fit, by, ...) {
 
 ############################################################################
 # HISTORY:
+# 2013-10-09
+# o Now getSmoothLocusData() for CBS also returns column 'count'.
 # 2013-04-18
 # o Added getSmoothLocusData() for CBS.
 # o Created.
